==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/inputs/AnalyticsApplicationInputsKinesisStreamArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.inputs

import com.pulumi.aws.kinesis.inputs.AnalyticsApplicationInputsKinesisStreamArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceArn The ARN of the Kinesis Stream.
 * @property roleArn The ARN of the IAM Role used to access the stream.
 */
public data class AnalyticsApplicationInputsKinesisStreamArgs(
    public val resourceArn: Output<String>,
    public val roleArn: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.kinesis.inputs.AnalyticsApplicationInputsKinesisStreamArgs> {
    override fun toJava(): com.pulumi.aws.kinesis.inputs.AnalyticsApplicationInputsKinesisStreamArgs =
        com.pulumi.aws.kinesis.inputs.AnalyticsApplicationInputsKinesisStreamArgs.builder()
            .resourceArn(resourceArn.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AnalyticsApplicationInputsKinesisStreamArgs].
 */
@PulumiTagMarker
public class AnalyticsApplicationInputsKinesisStreamArgsBuilder internal constructor() {
    private var resourceArn: Output<String>? = null

    private var roleArn: Output<String>? = null

    /**
     * @param value The ARN of the Kinesis Stream.
     */
    @JvmName("cncnsbsrrqrnyign")
    public suspend fun resourceArn(`value`: Output<String>) {
        this.resourceArn = value
    }

    /**
     * @param value The ARN of the IAM Role used to access the stream.
     */
    @JvmName("wwvvqebfnwuuscxa")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The ARN of the Kinesis Stream.
     */
    @JvmName("fksexbgdxlkapqfc")
    public suspend fun resourceArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceArn = mapped
    }

    /**
     * @param value The ARN of the IAM Role used to access the stream.
     */
    @JvmName("vvbeijfpaicnyosa")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    internal fun build(): AnalyticsApplicationInputsKinesisStreamArgs =
        AnalyticsApplicationInputsKinesisStreamArgs(
            resourceArn = resourceArn ?: throw PulumiNullFieldException("resourceArn"),
            roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/kinesis/kotlin/inputs/AnalyticsApplicationInputsKinesisStreamArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.kinesis.kotlin.inputs

import com.pulumi.aws.kinesis.inputs.AnalyticsApplicationInputsKinesisStreamArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceArn The ARN of the Kinesis Stream.
 * @property roleArn The ARN of the IAM Role used to access the stream.
 */
public data class AnalyticsApplicationInputsKinesisStreamArgs(
    public val resourceArn: Output<String>,
    public val roleArn: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.kinesis.inputs.AnalyticsApplicationInputsKinesisStreamArgs> {
    override fun toJava(): com.pulumi.aws.kinesis.inputs.AnalyticsApplicationInputsKinesisStreamArgs =
        com.pulumi.aws.kinesis.inputs.AnalyticsApplicationInputsKinesisStreamArgs.builder()
            .resourceArn(resourceArn.applyValue({ args0 -> args0 }))
            .roleArn(roleArn.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AnalyticsApplicationInputsKinesisStreamArgs].
 */
@PulumiTagMarker
public class AnalyticsApplicationInputsKinesisStreamArgsBuilder internal constructor() {
    private var resourceArn: Output<String>? = null

    private var roleArn: Output<String>? = null

    /**
     * @param value The ARN of the Kinesis Stream.
     */
    @JvmName("eksvuyoakkykdukx")
    public suspend fun resourceArn(`value`: Output<String>) {
        this.resourceArn = value
    }

    /**
     * @param value The ARN of the IAM Role used to access the stream.
     */
    @JvmName("uaerhtwjfaogndpk")
    public suspend fun roleArn(`value`: Output<String>) {
        this.roleArn = value
    }

    /**
     * @param value The ARN of the Kinesis Stream.
     */
    @JvmName("rybysneakvnvoiex")
    public suspend fun resourceArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceArn = mapped
    }

    /**
     * @param value The ARN of the IAM Role used to access the stream.
     */
    @JvmName("kmyvblisuiybrgmn")
    public suspend fun roleArn(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleArn = mapped
    }

    internal fun build(): AnalyticsApplicationInputsKinesisStreamArgs =
        AnalyticsApplicationInputsKinesisStreamArgs(
            resourceArn = resourceArn ?: throw PulumiNullFieldException("resourceArn"),
            roleArn = roleArn ?: throw PulumiNullFieldException("roleArn"),
        )
}
